#
# spec file for package libaacs
#
# Copyright (c) 2022 Packman Team <packman@links2linux.de>
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


%define sover   0
Name:           libaacs
Version:        0.11.1
Release:        1699.1.pm.26
Summary:        Open implentation of AACS specification
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://www.videolan.org/developers/libaacs.html
Source:         https://download.videolan.org/videolan/%{name}/%{version}/%{name}-%{version}.tar.bz2
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
libaacs is a research project to implement the Advanced Access Content System specification.
This research project provides, through an open-source library, a way to understand how the AACS works.

%package -n %{name}%{sover}
Summary:        Open implentation of AACS specification
Group:          System/Libraries

%description -n %{name}%{sover}
libaacs is a research project to implement the Advanced Access Content System specification.
This research project provides, through an open-source library, a way to understand how the AACS works.

%package devel
Summary:        Open implentation of AACS specification - Development files
Group:          Development/Languages/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel
libaacs is a research project to implement the Advanced Access Content System specification.
This research project provides, through an open-source library, a way to understand how the AACS works.

%prep
%autosetup

%build
autoreconf -fvi
%configure \
    --disable-static \
    --disable-silent-rules
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license COPYING
%{_bindir}/aacs_info
%{_libdir}/%{name}.so.%{sover}
%{_libdir}/%{name}.so.%{sover}.*

%files devel
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}/

%changelog
* Sun Apr 10 2022 enzokiel@kabelmail.de
- Update to version 0.11.1
  * Faster start with MacOS when disc does not use bus encryption.
  * Improve error logging.
  * Improve error resilience.
* Sat Sep  5 2020 Luigi Baldoni <aloisio@gmx.com>
  2020-07-22: Version 0.11.0
  * Add more AACS2 support (still not complete).
  * Add support for partial unit keys in KEYDB.CFG.
  * Improve opening of UHD discs (~ 10 seconds faster).
  * Improve large KEYDB.CFG parsing (~ 4 times faster).
  * Improve error resilience.
  * Reduce memory usage (does not depend on config file size
    anymore).
  * Fix segfault on macOS when MMC opening fails.
  * Fix memory leak with multiple UK entries in KEYDB.cfg file.
  * Fix AACS2 with multiple unit keys.
  * Fix include flags order (do not include wrong headers
    outside of source tree).
* Mon Apr 27 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.10.0
  * Add support for AACS2 content certificate.
  * Add aacs_set_key_caching().
  * Add aacs_error_str().
  * Issue a warning when using AACS2 capable drive.
  * Fix parsing title entries from multiple KEYDB.cfg files.
  * Fix memory leak with multiple KEYDB.cfg files.
  * Fix data corruption when structs are not packed.
- Spec cleanup
* Tue May 16 2017 joerg.lorenzen@ki.tng.de
- update to 0.9.0
  * Add aacs_decrypt_bus().
  * Add aacs_get_bdj_root_cert_hash().
  * Add aacs_get_content_cert_id().
  * Add support for unencrypted content in AACS-enabled discs.
  * Improve error resilience.
  * Improve support for broken discs (use on-disc backup files).
  * Verify content certificate signature.
  * Load and merge multiple KEYDB.cfg files.
  * Fix build with gcrypt < 1.6.0.
  * Fix possible crash (debug log output that includes discid).
  * Fix config file path issues in Windows (non-ASCII paths).
  * Fix dll exports in Windows.
  * Fix resource leaks.
  * Reduced memory footprint.
* Wed Feb 22 2017 scarabeus@opensuse.org
- Cleanup a bit with spec-cleaner
- Remove sle11 support
- Drop no longer needed patch libaacs-0.6.0-bison-2.3-compatibility.patch
* Sun Mar 15 2015 joerg.lorenzen@ki.tng.de
- update to 0.8.1
  * Accept NULL mount / device path when application handles file system access.
  * Fix FreeBSD build.
  * Do not require pthread with gcrypt >= 1.6.0.
* Tue Jan 27 2015 joerg.lorenzen@ki.tng.de
- update to 0.8.0
  * Add improved file system interface
  * Support opening raw devices
  * Reduce log level of failed PMSN query
  * Optimizations
* Wed Dec 17 2014 joerg.lorenzen@ki.tng.de
- update to 0.7.1
  * Add support for gcrypt 1.6.0.
  * Do not retrieve MKB using MMC commands during AACS-Auth.
* Fri Apr 25 2014 dnh@opensuse.org
- update to 0.7.0
  * Add aacs_get_device_binding_id() and aacs_get_device_nonce().
  * Add aacs_get_mk().
  * Add support for bus encryption.
  * Add support for device keys.
  * Add support for internal keys.
  * Fix reading PMSN.
  * Fix reporting AACS version from AACS drive feature.
  * Calculate bus key and use it to verify message authentication codes.
  * Do not fail if VID is known but config file does not exist.
  * Improve validating keys in KEYDB.cfg.
  * Update KEYDB.cfg format (still backwards compatible):
  * Host nonce and host key point are optional.
  * Add device key UV values and masks.
  * Build system updates.
  * Drop support for compile-time PATCHED_DRIVE flag.
* Sat Mar 16 2013 obs@botter.cc
- update to 0.6.0
  * Added reading of PMSN (Pre-recorded Media Serial Number)
  * Fix resource leak
  * Use proper paths to search for keydb and friends on Darwin.
  * Build fixes and improvements
- 0.5.0
  * Support for Mac OS X using IOKit
  * Fix AACS detection failure in some Win32 systems
- 0.4.0
  * Added aacs_open2() and error codes
  * Renamed libaacs_test to aacs_info
  * Added aacs_get_mkb_version()
  * Fixed memory leaks
  * Fixed buffer overflow
  * Added revocation list caching
  * Check host certificates against latest seen revocation list
- 0.3.1
  * Added configure option for libgcrypt prefix
  * Fixed building Win32 DLL
  * Fixed segfault when mount point path can't be resolved
  * Do not export internal symbols from generated parser/lexer
  * Do not distribute generated parser files
  * Check for libgpg-error. Link against it when needed.
  * Distribute README.txt
  * Added ChangeLog
* Sat Dec  3 2011 pascal.bleser@opensuse.org
- update to 0.3.0 (first proper release)
* Wed Nov 16 2011 dimstar@opensuse.org
- Initial package, git snapshot 2011-11-16.
